@@ -16,9 +16,6 @@ sf_to_geoda <- function(sf_obj, with_table=TRUE) {
   if (!requireNamespace("sf", quietly = TRUE)) {
     stop("package sf not available: install first?")
   }
-  if (!requireNamespace("wkb", quietly = TRUE)) {
-    stop("package wkb not available: install first?")
-  }
 
   # geometries
   sf_geom <- sf::st_geometry(sf_obj)
@@ -88,7 +85,7 @@ as.geoda <- function(obj, with_table=TRUE) {
     return (sp_to_geoda(obj, with_table))
   } else if (length(class(obj)) == 2 && class(obj)[[1]] == "sf") {
     # fall back to try sf object
-    return (sf_to_geoda(obj, with_table=TRUE))
+    return (sf_to_geoda(obj, with_table))
   } else {
     stop("as.geoda() takes either an 'sf' or 'sp' object.")
   }
