@@ -34,7 +34,8 @@ public:
 
     virtual void PermLocalSA(int cnt, int perm, const std::vector<int> &permNeighbors, std::vector<double>& permutedSA);
 
-    virtual void PermLocalSA(int cnt, int perm, int numNeighbors, const int* permNeighbors, std::vector<double>& permutedSA){}
+    virtual void PermLocalSA(int cnt, int perm, int numNeighbors, const int* permNeighbors, std::vector<double>&
+            permutedSA);
 
     virtual uint64_t CountLargerSA(int cnt, const std::vector<double>& permutedSA);
 
